@@ -16,7 +16,7 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(1, 5, 5, 1, 3, 3, 1)
-            self.assertEquals(6, len(os.listdir(inject_dir)))
+            self.assertEquals(5, len(os.listdir(inject_dir)))
             self.assertEquals([1], matrix.sectors)
             self.assertAlmostEqual(0.47, matrix.mass, 2)
             self.assertAlmostEqual(0.44, matrix.massmin, 2)
@@ -33,9 +33,9 @@ class TestsMatrix(unittest.TestCase):
             self.assertAlmostEqual(0.076, matrix.rstar_min.value, 3)
             self.assertAlmostEqual(0.284, matrix.rstar_max.value, 3)
             self.assertEquals(".", matrix.dir)
-            matrix.recovery(multiprocessing.cpu_count() - 1, inject_dir, 5, 0)
+            matrix.recovery(inject_dir, 5, 0)
             matrix.plot_results(target, inject_dir)
-            self.assertEquals(7, len(os.listdir(inject_dir)))
+            self.assertEquals(8, len(os.listdir(inject_dir)))
         finally:
             if inject_dir is not None:
                 shutil.rmtree(inject_dir, ignore_errors=True)
@@ -46,9 +46,9 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(1, 5, 5, 1, 3, 3, 1)
-            matrix.recovery(multiprocessing.cpu_count() - 1, inject_dir, 5, 0)
+            matrix.recovery(inject_dir, 5, 0)
             matrix.plot_results(target, inject_dir)
-            self.assertEquals(8, len(os.listdir(inject_dir)))
+            self.assertEquals(9, len(os.listdir(inject_dir)))
         finally:
             if inject_dir is not None:
                 shutil.rmtree(inject_dir, ignore_errors=True)
@@ -59,7 +59,7 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(1, 5, 5.1, 2, 3, 3.1, 2)
-            self.assertEquals(9, len(os.listdir(inject_dir)))
+            self.assertEquals(8, len(os.listdir(inject_dir)))
         finally:
             if inject_dir is not None:
                 shutil.rmtree(inject_dir, ignore_errors=True)
@@ -70,7 +70,7 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(2, 5, 5, 1, 3, 3, 1)
-            self.assertEquals(7, len(os.listdir(inject_dir)))
+            self.assertEquals(6, len(os.listdir(inject_dir)))
         finally:
             if inject_dir is not None:
                 shutil.rmtree(inject_dir, ignore_errors=True)
@@ -78,7 +78,7 @@ class TestsMatrix(unittest.TestCase):
     def test_transit_mask(self):
         target = "TIC 305048087"
         matrix = MATRIX(target, [2], ".", exposure_time=120)
-        matrix.retrieve_object_data()
+        inject_dir = matrix.retrieve_object_data()
         power_args = {"transit_template": "default", "period_min": 1, "period_max": 10,
                       "n_transits_min": 2, "show_progress_bar": True, "use_threads": multiprocessing.cpu_count() - 1,
                       "R_star": matrix.radius, "R_star_min": matrix.radiusmin, "R_star_max": matrix.radiusmax,
@@ -152,7 +152,7 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(1, 5, 5, 1, 3, 3, 1)
-            self.assertEquals(6, len(os.listdir(inject_dir)))
+            self.assertEquals(5, len(os.listdir(inject_dir)))
             self.assertEquals((0.2, 0.5), matrix.star_info.ld_coefficients)
             self.assertEquals(2000, matrix.star_info.teff)
             self.assertAlmostEqual(0.7, matrix.star_info.mass)
@@ -168,7 +168,7 @@ class TestsMatrix(unittest.TestCase):
         inject_dir = None
         try:
             inject_dir = matrix.inject(1, 5, 5, 1, 3, 3, 1)
-            self.assertEquals(6, len(os.listdir(inject_dir)))
+            self.assertEquals(5, len(os.listdir(inject_dir)))
             self.assertEquals((0.1258, 0.235), matrix.star_info.ld_coefficients)
             self.assertEquals(31000.0, matrix.star_info.teff)
             self.assertAlmostEqual(0.47, matrix.star_info.mass)
